@@ -14,7 +14,6 @@ support: 工具
 ├── milvus
 └── 一些常用功能函数
 """
-import logging
 import os
 from urllib.parse import urlparse, parse_qs
 
@@ -35,7 +34,7 @@ def __get_exists_file(file: str):
 # 文件目录、项目跟目录、HOME环境目录, 加载.env环境文件
 env_file = __get_exists_file('.env')
 env_file and __load_dotenv(env_file)
-logging.info("current env file path is:[%s]" % env_file)
+# logging.info("current env file path is:[%s]" % env_file)
 
 
 # MYSQL
